agentle.mcp.resources.text\_resources
=====================================

.. automodule:: agentle.mcp.resources.text_resources

   
.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   configuration_file
   json_data
   log_file
   plain_text
   source_code
   textfyable
   xml_data
